@@ -22,8 +22,6 @@
 #define E_CAL_BACKEND_EWS_UTILS_H
 
 #include <libecal/libecal.h>
-#include <libical/icaltime.h>
-#include <libical/icaltimezone.h>
 
 #include "server/e-ews-connection.h"
 #include "server/e-ews-item-change.h"
@@ -31,8 +29,6 @@
 #include "e-cal-backend-ews.h"
 
 G_BEGIN_DECLS
-#define EDC_ERROR(_code) e_data_cal_create_error (_code, NULL)
-#define EDC_ERROR_EX(_code, _msg) e_data_cal_create_error (_code, _msg)
 
 #define MINUTES_IN_HOUR 60
 #define SECS_IN_MINUTE 60
@@ -40,14 +36,14 @@ G_BEGIN_DECLS
 typedef struct {
 	EEwsConnection *connection;
 	ETimezoneCache *timezone_cache;
-	icaltimezone *default_zone;
+	ICalTimezone *default_zone;
 	gchar *user_email;
 	gchar *response_type; /* Accept */
 	GSList *users;
 	ECalComponent *comp;
 	ECalComponent *old_comp;
-	icalcomponent *icalcomp;
-	icalcomponent *vcalendar; /* can be NULL, parent of icalcomp, where timezones can be eventually found */
+	ICalComponent *icomp;
+	ICalComponent *vcalendar; /* can be NULL, parent of icomp, where timezones can be eventually found */
 	gchar *item_id;
 	gchar *change_key;
 	EEwsItemChangeType change_type;
@@ -56,17 +52,17 @@ typedef struct {
 	time_t end;
 } EwsCalendarConvertData;
 
-const gchar *e_ews_collect_organizer (icalcomponent *comp);
-void e_ews_collect_attendees (icalcomponent *comp, GSList **required, GSList **optional, GSList **resource, gboolean *out_rsvp_requested);
+const gchar *e_ews_collect_organizer (ICalComponent *comp);
+void e_ews_collect_attendees (ICalComponent *comp, GSList **required, GSList **optional, GSList **resource, gboolean *out_rsvp_requested);
 
 void ewscal_set_timezone (ESoapMessage *msg, const gchar *name, EEwsCalendarTimeZoneDefinition *tzd);
-void ewscal_set_meeting_timezone (ESoapMessage *msg, icaltimezone *icaltz);
-void ewscal_set_reccurence (ESoapMessage *msg, icalproperty *rrule, icaltimetype *dtstart);
-void ewscal_set_reccurence_exceptions (ESoapMessage *msg, icalcomponent *comp);
+void ewscal_set_meeting_timezone (ESoapMessage *msg, ICalTimezone *icaltz);
+void ewscal_set_reccurence (ESoapMessage *msg, ICalProperty *rrule, ICalTime *dtstart);
+void ewscal_set_reccurence_exceptions (ESoapMessage *msg, ICalComponent *comp);
 gchar *e_ews_extract_attachment_id_from_uri (const gchar *uri);
-void ews_set_alarm (ESoapMessage *msg, ECalComponent *comp, ETimezoneCache *timezone_cache, icalcomponent *vcalendar, gboolean with_due_by);
+void ews_set_alarm (ESoapMessage *msg, ECalComponent *comp, ETimezoneCache *timezone_cache, ICalComponent *vcalendar, gboolean with_due_by);
 gint ews_get_alarm (ECalComponent *comp);
-void e_ews_clean_icalcomponent (icalcomponent *icalcomp);
+void e_ews_clean_icomponent (ICalComponent *icomp);
 
 const gchar *e_cal_backend_ews_tz_util_get_msdn_equivalent (const gchar *ical_tz_location);
 const gchar *e_cal_backend_ews_tz_util_get_ical_equivalent (const gchar *msdn_tz_location);
@@ -79,14 +75,13 @@ gboolean e_cal_backend_ews_clear_reminder_is_set (ESoapMessage *msg, gpointer us
 gboolean e_cal_backend_ews_prepare_set_free_busy_status (ESoapMessage *msg,gpointer user_data, GError **error);
 gboolean e_cal_backend_ews_prepare_accept_item_request (ESoapMessage *msg, gpointer user_data, GError **error);
 
-guint e_cal_backend_ews_rid_to_index (icaltimezone *timezone, const gchar *rid, icalcomponent *comp, GError **error);
+guint e_cal_backend_ews_rid_to_index (ICalTimezone *timezone, const gchar *rid, ICalComponent *comp, GError **error);
 
-struct icaltimetype
-		e_cal_backend_ews_get_datetime_with_zone	(ETimezoneCache *timezone_cache,
-								 icalcomponent *vcalendar,
-								 icalcomponent *comp,
-								 icalproperty_kind prop_kind,
-								 struct icaltimetype (* get_func) (const icalproperty *prop));
+ICalTime *	e_cal_backend_ews_get_datetime_with_zone	(ETimezoneCache *timezone_cache,
+								 ICalComponent *vcalendar,
+								 ICalComponent *comp,
+								 ICalPropertyKind prop_kind,
+								 ICalTime * (* get_func) (ICalProperty *prop));
 
 G_END_DECLS
 
