@@ -30,21 +30,6 @@
 
 #define OFFICE365_RESOURCE "https://outlook.office.com"
 
-#define OFFICE365_SCOPE "openid offline_access profile " \
-	"Mail.ReadWrite " \
-	"Mail.ReadWrite.Shared " \
-	"Mail.Send " \
-	"Mail.Send.Shared " \
-	"Calendars.ReadWrite " \
-	"Calendars.ReadWrite.Shared " \
-	"Contacts.ReadWrite " \
-	"Contacts.ReadWrite.Shared " \
-	"Tasks.ReadWrite " \
-	"Tasks.ReadWrite.Shared " \
-	"MailboxSettings.ReadWrite " \
-	"People.Read " \
-	"User.ReadBasic.All"
-
 struct _EOAuth2ServiceOffice365Private
 {
 	GMutex string_cache_lock;
@@ -253,7 +238,6 @@ eos_office365_prepare_authentication_uri_query (EOAuth2Service *service,
 
 	e_oauth2_service_util_set_to_form (uri_query, "response_mode", "query");
 	e_oauth2_service_util_set_to_form (uri_query, "prompt", "login");
-	e_oauth2_service_util_set_to_form (uri_query, "scope", OFFICE365_SCOPE);
 	e_oauth2_service_util_set_to_form (uri_query, "resource", OFFICE365_RESOURCE);
 }
 
@@ -321,7 +305,6 @@ eos_office365_prepare_refresh_token_form (EOAuth2Service *service,
 {
 	g_return_if_fail (form != NULL);
 
-	e_oauth2_service_util_set_to_form (form, "scope", OFFICE365_SCOPE);
 	e_oauth2_service_util_set_to_form (form, "resource", OFFICE365_RESOURCE);
 	e_oauth2_service_util_set_to_form (form, "redirect_uri", e_oauth2_service_get_redirect_uri (service, source));
 }
