@@ -33,6 +33,8 @@ struct _ESourceEwsFolderPrivate {
 	gboolean is_public;
 	guint freebusy_weeks_before;
 	guint freebusy_weeks_after;
+	gboolean use_primary_address;
+	gboolean fetch_gal_photos;
 };
 
 enum {
@@ -44,7 +46,9 @@ enum {
 	PROP_FOREIGN_MAIL,
 	PROP_FREEBUSY_WEEKS_BEFORE,
 	PROP_FREEBUSY_WEEKS_AFTER,
-	PROP_PUBLIC
+	PROP_PUBLIC,
+	PROP_USE_PRIMARY_ADDRESS,
+	PROP_FETCH_GAL_PHOTOS
 };
 
 G_DEFINE_TYPE (
@@ -106,6 +110,18 @@ source_ews_folder_set_property (GObject *object,
 				E_SOURCE_EWS_FOLDER (object),
 				g_value_get_boolean (value));
 			return;
+
+		case PROP_USE_PRIMARY_ADDRESS:
+			e_source_ews_folder_set_use_primary_address (
+				E_SOURCE_EWS_FOLDER (object),
+				g_value_get_boolean (value));
+			return;
+
+		case PROP_FETCH_GAL_PHOTOS:
+			e_source_ews_folder_set_fetch_gal_photos (
+				E_SOURCE_EWS_FOLDER (object),
+				g_value_get_boolean (value));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -173,6 +189,20 @@ source_ews_folder_get_property (GObject *object,
 				e_source_ews_folder_get_public (
 				E_SOURCE_EWS_FOLDER (object)));
 			return;
+
+		case PROP_USE_PRIMARY_ADDRESS:
+			g_value_set_boolean (
+				value,
+				e_source_ews_folder_get_use_primary_address (
+				E_SOURCE_EWS_FOLDER (object)));
+			return;
+
+		case PROP_FETCH_GAL_PHOTOS:
+			g_value_set_boolean (
+				value,
+				e_source_ews_folder_get_fetch_gal_photos (
+				E_SOURCE_EWS_FOLDER (object)));
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -313,6 +343,32 @@ e_source_ews_folder_class_init (ESourceEwsFolderClass *class)
 			G_PARAM_CONSTRUCT |
 			G_PARAM_STATIC_STRINGS |
 			E_SOURCE_PARAM_SETTING));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_USE_PRIMARY_ADDRESS,
+		g_param_spec_boolean (
+			"use-primary-address",
+			"Use Primary Address",
+			"Whether online GAL should use only the primary contact address",
+			FALSE,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
+			G_PARAM_STATIC_STRINGS |
+			E_SOURCE_PARAM_SETTING));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_FETCH_GAL_PHOTOS,
+		g_param_spec_boolean (
+			"fetch-gal-photos",
+			"Fetch GAL Photos",
+			"Whether fetch photos for GAL contacts",
+			TRUE,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT |
+			G_PARAM_STATIC_STRINGS |
+			E_SOURCE_PARAM_SETTING));
 }
 
 static void
@@ -597,3 +653,47 @@ e_source_ews_folder_set_public (ESourceEwsFolder *extension,
 
 	g_object_notify (G_OBJECT (extension), "public");
 }
+
+gboolean
+e_source_ews_folder_get_use_primary_address (ESourceEwsFolder *extension)
+{
+	g_return_val_if_fail (E_IS_SOURCE_EWS_FOLDER (extension), FALSE);
+
+	return extension->priv->use_primary_address;
+}
+
+void
+e_source_ews_folder_set_use_primary_address (ESourceEwsFolder *extension,
+					     gboolean use_primary_address)
+{
+	g_return_if_fail (E_IS_SOURCE_EWS_FOLDER (extension));
+
+	if ((extension->priv->use_primary_address ? 1 : 0) == (use_primary_address ? 1 : 0))
+		return;
+
+	extension->priv->use_primary_address = use_primary_address;
+
+	g_object_notify (G_OBJECT (extension), "use-primary-address");
+}
+
+gboolean
+e_source_ews_folder_get_fetch_gal_photos (ESourceEwsFolder *extension)
+{
+	g_return_val_if_fail (E_IS_SOURCE_EWS_FOLDER (extension), FALSE);
+
+	return extension->priv->fetch_gal_photos;
+}
+
+void
+e_source_ews_folder_set_fetch_gal_photos (ESourceEwsFolder *extension,
+					  gboolean fetch_gal_photos)
+{
+	g_return_if_fail (E_IS_SOURCE_EWS_FOLDER (extension));
+
+	if ((extension->priv->fetch_gal_photos ? 1 : 0) == (fetch_gal_photos ? 1 : 0))
+		return;
+
+	extension->priv->fetch_gal_photos = fetch_gal_photos;
+
+	g_object_notify (G_OBJECT (extension), "fetch-gal-photos");
+}
